@@ -52,7 +52,6 @@ try:
 except ImportError:
     import mock
 import pkg_resources
-import six
 import testscenarios
 import testtools
 from testtools import matchers
@@ -218,18 +217,18 @@ class CreatePackages(fixtures.Fixture):
     """
 
     defaults = {
-        'setup.py': textwrap.dedent(six.u("""\
+        'setup.py': textwrap.dedent(u"""\
             #!/usr/bin/env python
             import setuptools
             setuptools.setup(
                 setup_requires=['pbr'],
                 pbr=True,
             )
-        """)),
-        'setup.cfg': textwrap.dedent(six.u("""\
+        """),
+        'setup.cfg': textwrap.dedent(u"""\
             [metadata]
             name = {pkg_name}
-        """))
+        """)
     }
 
     def __init__(self, packages):
@@ -414,9 +413,9 @@ class TestPackagingWheels(base.BaseTestCase):
         built_package_dir = os.path.join(
             self.extracted_wheel_dir, 'pbr_testpackage')
         static_object_filename = 'testext.so'
-        soabi = get_soabi()
-        if soabi:
-            static_object_filename = 'testext.{0}.so'.format(soabi)
+        ext_suffix = sysconfig.get_config_var('EXT_SUFFIX')
+        if ext_suffix is not None:
+            static_object_filename = 'testext' + ext_suffix
         static_object_path = os.path.join(
             built_package_dir, static_object_filename)
 
